@@ -31,7 +31,9 @@ import subprocess
 import sys
 import zipfile
 
-__version__ = "0.24.1"
+from template import compile_template
+
+__version__ = "0.26.0"
 
 is_windows = os.name == "nt"
 
@@ -162,12 +164,26 @@ library."""
         "os": "win64" if is_windows else "unix",
         "c": cli_args.c,
         "cpp": not cli_args.c,
-        "suppress": False,
         "c_header": False,
         "include_source": False,
         "has_source": True,
         "cpus": os.cpu_count(),
+        "pm_name": "",
     }
+    package_manager = ask(
+        "Package manager to use ([N]one/[c]onan/[v]cpkg)",
+        cli_args.package_manager or "n",
+        mapper=lambda v: v[0:1].lower(),
+        predicate=lambda v: v in ["n", "c", "v"],
+        header="""\
+Choosing Conan requires it to be installed. Choosing vcpkg requires the
+VCPKG_ROOT environment variable to be setup to vcpkg's root directory.""",
+    )
+    d["vcpkg"] = package_manager == "v"
+    d["conan"] = package_manager == "c"
+    d["pm"] = package_manager != "n"
+    if d["pm"]:
+        d["pm_name"] = "conan" if d["conan"] else "vcpkg"
     d["uc_name"] = d["name"].upper().replace("-", "_")
     if d["type_id"] != "e":
         key = "c_examples" if cli_args.c else "cpp_examples"
@@ -179,13 +195,14 @@ library."""
         )
         d[key] = value
         d["examples"] = value
-    if d["type_id"] == "s" and d["cpp"]:
-        d["suppress"] = True
     if d["type_id"] == "e":
         d["include_source"] = True
     if d["type_id"] == "h":
         d["has_source"] = False
     d["c_header"] = d["c"] and d["type_id"] == "h"
+    d["exe"] = d["type_id"] == "e"
+    d["lib"] = d["type_id"] == "s"
+    d["header"] = d["type_id"] == "h"
     return d
 
 
@@ -194,28 +211,16 @@ def mkdir(path):
 
 
 def write_file(path, d, overwrite, zip_path):
-    if not overwrite and os.path.exists(path):
-        return
-
-    def replacer(match):
-        query = match.group(1)
-        expected = True
-        if query.endswith("_not"):
-            query = query[:-4]
-            expected = False
-        if query == "type":
-            mapping = {"exe": "e", "header": "h", "shared": "s"}
-            actual = mapping[match.group(2)] == d["type_id"]
-            if actual == expected:
-                return match.group(3)
-        elif query == "if" and d[match.group(2)] == expected:
-            return match.group(3)
-        return ""
-
-    regex = re.compile("{((?:type|if)(?:_not)?) ([^}]+)}(.+?){end}", re.DOTALL)
-    contents = regex.sub(replacer, zip_path.read_text(encoding="UTF-8"))
-    with open(path, "w", encoding="UTF-8", newline="\n") as f:
-        f.write(contents % d)
+    if overwrite or not os.path.exists(path):
+        renderer = compile_template(zip_path.read_text(encoding="UTF-8"), d)
+        # noinspection PyBroadException
+        try:
+            contents = renderer()
+        except Exception:
+            print(f"Error while rendering {path}", file=sys.stderr)
+            raise
+        with open(path, "w", encoding="UTF-8", newline="\n") as f:
+            f.write(contents)
 
 
 def should_write_examples(d, at):
@@ -225,24 +230,56 @@ def should_write_examples(d, at):
         return d["cpp_examples"]
 
 
+def should_install_file(name, d):
+    if name == "vcpkg.json" and not d["vcpkg"]:
+        return False
+    if name == "conanfile.txt" and not d["conan"]:
+        return False
+    if name == "install-config.cmake" and d["exe"]:
+        return False
+    if name == "windows-set-path.cmake" and d["pm"]:
+        return False
+    if name == "install-script.cmake" and not d["exe"]:
+        return False
+    if name == "header_impl.c" and (not d["c_header"] or not d["pm"]):
+        return False
+    if name == "clang-11.profile" and not d["conan"]:
+        return False
+    return True
+
+
+def transform_path(path, d):
+    if not d["exe"] and d["pm"] and path.endswith("install-config.cmake"):
+        return f"{path}.in"
+    if d["c"] and d["pm"] and path.endswith("_test.c"):
+        return f"{path}pp"
+    return path
+
+
 def write_dir(path, d, overwrite, zip_path):
     for entry in zip_path.iterdir():
         name = entry.name.replace("__name__", d["name"])
         next_path = os.path.join(path, name)
         if entry.is_file():
-            write_file(next_path, d, overwrite, entry)
+            if should_install_file(name, d):
+                write_file(transform_path(next_path, d), d, overwrite, entry)
         elif name != "example" or should_write_examples(d, entry.at):
             mkdir(next_path)
             write_dir(next_path, d, overwrite, entry)
 
 
 def determine_git_version():
+    search_pattern = r"\d+(\.\d+)+"
     git_version_out = \
         subprocess.run("git --version", shell=True, capture_output=True)
     if git_version_out.returncode != 0:
         return None
-    git_version_str = str(git_version_out.stdout[12:], sys.stdout.encoding)
-    git_version = list(map(int, git_version_str.rstrip().split(".")[:3]))
+    git_version_out = str(git_version_out.stdout, sys.stdout.encoding)
+    git_version_match = re.search(search_pattern, git_version_out)
+    if not git_version_match:
+        return None
+    git_version_str = git_version_match.group(0)
+    git_version = list(map(int, git_version_str.rstrip().split(".")))
     if len(git_version) < 3:
         git_version += [0] * (3 - len(git_version))
     return tuple(git_version)
@@ -269,11 +306,15 @@ push the project with the following commands from the project directory:
 
 def print_tips(d):
     config = " --config Debug" if is_windows else ""
+    conan = ""
+    if d["conan"]:
+        conan = """
+    conan install . -if conan -s build_type=Debug -b missing"""
     print(f"""\
 To get you started with the project in developer mode, you may configure,
 build, install and test with the following commands from the project directory,
 in that order:
-
+{conan}
     cmake --preset=dev
     cmake --build --preset=dev
     cmake --install build/dev{config} --prefix prefix
@@ -349,6 +390,10 @@ def vcpkg(d, zip):
         print(f"""'{d["name"]}' already exists""", file=sys.stderr)
         exit(1)
     mkdir(path)
+    for key in ["c", "pm", "exe", "conan", "vcpkg", "c_header"]:
+        d[key] = False
+    d["lib"] = d["type_id"] == "s"
+    d["header"] = d["type_id"] == "h"
     write_dir(path, d, False, zipfile.Path(zip, "templates/vcpkg/"))
     vcpkg_root = r"%VCPKG_ROOT:\=/%" if is_windows else "$VCPKG_ROOT"
     pwd = r"%cd:\=/%" if is_windows else "$PWD"
@@ -501,6 +546,12 @@ pass as the first flag to make a vcpkg port of <name> with type -s or -h",
         const="n",
         help="generate examples for a library",
     )
+    p.add_argument(
+        "-p",
+        metavar="pm",
+        dest="package_manager",
+        help="package manager to use (Options are: conan, vcpkg)",
+    )
     args = p.parse_args()
     if args.dummy:
         p.print_help()
